@@ -13,7 +13,7 @@ import dbt.utils
 
 
 # note that this isn't an adapter macro, so just a single underscore
-GET_RELATIONS_MACRO_NAME = 'postgres_get_relations'
+GET_RELATIONS_MACRO_NAME = "postgres_get_relations"
 
 
 @dataclass
@@ -25,16 +25,15 @@ class PostgresIndexConfig(dbtClassMixin):
     def render(self, relation):
         # We append the current timestamp to the index name because otherwise
         # the index will only be created on every other run. See
-        # https://github.com/fishtown-analytics/dbt/issues/1945#issuecomment-576714925
+        # https://github.com/dbt-labs/dbt-core/issues/1945#issuecomment-576714925
         # for an explanation.
         now = datetime.utcnow().isoformat()
-        inputs = (self.columns +
-                  [relation.render(), str(self.unique), str(self.type), now])
-        string = '_'.join(inputs)
+        inputs = self.columns + [relation.render(), str(self.unique), str(self.type), now]
+        string = "_".join(inputs)
         return dbt.utils.md5(string)
 
     @classmethod
-    def parse(cls, raw_index) -> Optional['PostgresIndexConfig']:
+    def parse(cls, raw_index) -> Optional["PostgresIndexConfig"]:
         if raw_index is None:
             return None
         try:
@@ -42,13 +41,11 @@ class PostgresIndexConfig(dbtClassMixin):
             return cls.from_dict(raw_index)
         except ValidationError as exc:
             msg = dbt.exceptions.validator_error_message(exc)
-            dbt.exceptions.raise_compiler_error(
-                f'Could not parse index config: {msg}'
-            )
+            dbt.exceptions.raise_compiler_error(f"Could not parse index config: {msg}")
         except TypeError:
             dbt.exceptions.raise_compiler_error(
-                f'Invalid index config:\n'
-                f'  Got: {raw_index}\n'
+                f"Invalid index config:\n"
+                f"  Got: {raw_index}\n"
                 f'  Expected a dictionary with at minimum a "columns" key'
             )
 
@@ -68,7 +65,7 @@ class PostgresAdapter(SQLAdapter):
 
     @classmethod
     def date_function(cls):
-        return 'now()'
+        return "now()"
 
     @available
     def verify_database(self, database):
@@ -77,11 +74,12 @@ class PostgresAdapter(SQLAdapter):
         expected = self.config.credentials.database
         if database.lower() != expected.lower():
             raise dbt.exceptions.NotImplementedException(
-                'Cross-db references not allowed in {} ({} vs {})'
-                .format(self.type(), database, expected)
+                "Cross-db references not allowed in {} ({} vs {})".format(
+                    self.type(), database, expected
+                )
             )
         # return an empty string on success so macros can call this
-        return ''
+        return ""
 
     @available
     def parse_index(self, raw_index: Any) -> Optional[PostgresIndexConfig]:
@@ -96,14 +94,10 @@ class PostgresAdapter(SQLAdapter):
 
         for (dep_schema, dep_name, refed_schema, refed_name) in table:
             dependent = self.Relation.create(
-                database=database,
-                schema=dep_schema,
-                identifier=dep_name
+                database=database, schema=dep_schema, identifier=dep_name
             )
             referenced = self.Relation.create(
-                database=database,
-                schema=refed_schema,
-                identifier=refed_name
+                database=database, schema=refed_schema, identifier=refed_name
             )
 
             # don't record in cache if this relation isn't in a relevant
@@ -112,13 +106,13 @@ class PostgresAdapter(SQLAdapter):
                 self.cache.add_link(referenced, dependent)
 
     def _get_catalog_schemas(self, manifest):
-        # postgres/redshift only allow one database (the main one)
+        # postgres only allow one database (the main one)
         schemas = super()._get_catalog_schemas(manifest)
         try:
             return schemas.flatten()
         except dbt.exceptions.RuntimeException as exc:
             dbt.exceptions.raise_compiler_error(
-                'Cross-db references not allowed in adapter {}: Got {}'.format(
+                "Cross-db references not allowed in adapter {}: Got {}".format(
                     self.type(), exc.msg
                 )
             )
@@ -132,11 +126,15 @@ class PostgresAdapter(SQLAdapter):
 
         self._link_cached_database_relations(schemas)
 
-    def _relations_cache_for_schemas(self, manifest):
-        super()._relations_cache_for_schemas(manifest)
+    def _relations_cache_for_schemas(self, manifest, cache_schemas=None):
+        super()._relations_cache_for_schemas(manifest, cache_schemas)
         self._link_cached_relations(manifest)
 
-    def timestamp_add_sql(
-        self, add_to: str, number: int = 1, interval: str = 'hour'
-    ) -> str:
+    def timestamp_add_sql(self, add_to: str, number: int = 1, interval: str = "hour") -> str:
         return f"{add_to} + interval '{number} {interval}'"
+
+    def valid_incremental_strategies(self):
+        """The set of standard builtin strategies which this adapter supports out-of-the-box.
+        Not used to validate custom strategies defined by end users.
+        """
+        return ["append", "delete+insert"]
